==> haskell-recv-0.1.1-70.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-FYzLFraRQnxDWsE7fLZoUg
key:                  recv-0.1.1-FYzLFraRQnxDWsE7fLZoUg
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  7d2670050c2910eca00ea8a9e5fc2e0b
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-FYzLFraRQnxDWsE7fLZoUg
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recv-0.1.1-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-2zF7O1pwsoXGqfuMlLk1gB
key:                  recv-0.1.1-2zF7O1pwsoXGqfuMlLk1gB
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  049d614e6bc7aa0a2fddef1f9f9e85b5
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-2zF7O1pwsoXGqfuMlLk1gB
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
